@@ -3,12 +3,6 @@
 
 #include <QObject>
 
-#ifdef STATIC_MAUIKIT
-#include "tagging.h"
-#else
-#include <MauiKit/tagging.h>
-#endif
-
 class Buho : public QObject
 {
     Q_OBJECT
