@@ -4,13 +4,8 @@
 #include "owl.h"
 #include <QObject>
 
-#ifdef STATIC_MAUIKIT
-#include "fmh.h"
-#include "mauilist.h"
-#else
-#include <MauiKit/fmh.h>
-#include <MauiKit/mauilist.h>
-#endif
+#include <MauiKit/Core/fmh.h>
+#include <MauiKit/Core/mauilist.h>
 
 class Booklet;
 class BooksSyncer;
