@@ -2,16 +2,9 @@
 #include "nextnote.h"
 #include "notessyncer.h"
 
-#ifdef STATIC_MAUIKIT
-#include "fm.h"
-#include "mauiaccounts.h"
-#include "mauiapp.h"
-#include "tagging.h"
-#else
-#include <MauiKit/fm.h>
-#include <MauiKit/mauiaccounts.h>
-#include <MauiKit/tagging.h>
-#endif
+#include <MauiKit/FileBrowsing/fm.h>
+#include <MauiKit/Core/mauiaccounts.h>
+#include <MauiKit/FileBrowsing/tagging.h>
 
 #include <algorithm>
 
@@ -35,7 +28,7 @@ Notes::Notes(QObject *parent)
             const auto mappedIndex = this->mappedIndex(this->indexOf(FMH::MODEL_KEY::ID, note[FMH::MODEL_KEY::ID]));
             if (mappedIndex >= 0) {
                 qDebug() << note[FMH::MODEL_KEY::MODIFIED];
-                note.insert(FMH::getFileInfoModel(note[FMH::MODEL_KEY::URL]));
+                note.insert(FMStatic::getFileInfoModel(note[FMH::MODEL_KEY::URL]));
                 qDebug() << note[FMH::MODEL_KEY::MODIFIED];
                 this->notes[mappedIndex] = note;
                 this->updateModel(mappedIndex, {});
@@ -44,8 +37,6 @@ Notes::Notes(QObject *parent)
     });
 
     connect(syncer, &NotesSyncer::noteReady, this, &Notes::appendNote);
-
-    this->syncer->getNotes();
 }
 
 void Notes::appendNote(FMH::MODEL note)
@@ -55,7 +46,7 @@ void Notes::appendNote(FMH::MODEL note)
         const auto lines = note[FMH::MODEL_KEY::CONTENT].split("\n");
         return lines.isEmpty() ? QString() : lines.first().trimmed();
     }();
-    note.insert(FMH::getFileInfoModel(note[FMH::MODEL_KEY::URL]));
+    note.insert(FMStatic::getFileInfoModel(note[FMH::MODEL_KEY::URL]));
     emit this->preItemAppended();
     this->notes << note;
     emit this->postItemAppended();
@@ -106,9 +97,28 @@ int Notes::indexOfNote(const QUrl &url)
     return this->indexOf(FMH::MODEL_KEY::PATH, url.toString());
 }
 
+int Notes::indexOfName(const QString &query)
+{
+    const auto it = std::find_if(this->items().constBegin(), this->items().constEnd(), [&](const FMH::MODEL &item) -> bool {
+            return item[FMH::MODEL_KEY::TITLE].startsWith(query, Qt::CaseInsensitive);
+        });
+
+        if (it != this->items().constEnd())
+            return this->mappedIndexFromSource(std::distance(this->items().constBegin(), it));
+        else
+            return -1;
+}
+
 QVariantMap Notes::get(const int &index) const
 {
     if (index >= this->notes.size() || index < 0)
         return QVariantMap();
     return FMH::toMap(this->notes.at(this->mappedIndex(index)));
 }
+
+
+void Notes::componentComplete()
+{
+    qDebug() << "Get the fucking notes";
+    this->syncer->getNotes();
+}
