@@ -2,17 +2,15 @@
 #include "abstractnotesprovider.h"
 #include "db/db.h"
 
-#ifdef STATIC_MAUIKIT
-#include "mauiaccounts.h"
-#else
-#include <MauiKit/mauiaccounts.h>
-#endif
+#include <MauiKit/Core/mauiaccounts.h>
 
 Syncer::Syncer(QObject *parent)
     : QObject(parent)
     , m_provider(nullptr) // online service handler
 {
     connect(MauiAccounts::instance(), &MauiAccounts::currentAccountChanged, [&](QVariantMap currentAccount) {
+
+        qDebug() << "Current account changed" << currentAccount;
         this->setAccount(FMH::toModel(currentAccount));
     });
 }
